@@ -23,6 +23,7 @@ crate cli
 
 can be used to query crate using SQL
 """
+from __future__ import print_function
 import inspect
 import json
 import logging
@@ -137,15 +138,23 @@ class CrateCmd(Cmd):
         if cols is None:
             cols = self.cols()
         rows = [list(map(self._transform_field, row)) for row in rows]
-        print(tabulate(rows, headers=cols, tablefmt=crate_fmt, floatfmt="",
-                       missingval=self.NULL))
+        out = tabulate(rows, headers=cols, tablefmt=crate_fmt, floatfmt="",
+                       missingval=self.NULL)
+        try:
+            print(out)
+        except UnicodeEncodeError:
+            try:
+                print(out.encode('utf-8').decode('ascii', 'replace'))
+            except UnicodeEncodeError:
+                print(out.encode('utf-8').decode('ascii', 'ignore'))
+            print('WARNING: Unicode characters found that cannot be displayed. Check your system locale.')
 
     def _transform_field(self, field):
         """transform field for displaying"""
         if isinstance(field, bool):
             return self.TRUE if field else self.FALSE
         elif isinstance(field, (list, dict)):
-            return json.dumps(field, sort_keys=True)
+            return json.dumps(field, sort_keys=True, ensure_ascii=False)
         else:
             return field
 
